summaryrefslogtreecommitdiffstats
path: root/kexi/main
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kexi/main
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kexi/main')
-rw-r--r--kexi/main/kexifinddialog.cpp6
-rw-r--r--kexi/main/keximainwindowimpl.cpp94
-rw-r--r--kexi/main/keximainwindowimpl.h2
-rw-r--r--kexi/main/keximainwindowimpl_p.h6
-rw-r--r--kexi/main/kexinewstuff.cpp2
-rw-r--r--kexi/main/kexistatusbar.cpp30
-rw-r--r--kexi/main/kexistatusbar.h12
-rw-r--r--kexi/main/printing/kexisimpleprintingengine.cpp4
-rw-r--r--kexi/main/printing/kexisimpleprintingpagesetup.cpp6
-rw-r--r--kexi/main/printing/kexisimpleprintingpagesetupbase.ui4
-rw-r--r--kexi/main/printing/kexisimpleprintpreviewwindow.cpp10
-rw-r--r--kexi/main/startup/KexiConnSelector.cpp6
-rw-r--r--kexi/main/startup/KexiConnSelectorBase.ui4
-rw-r--r--kexi/main/startup/KexiNewPrjTypeSelector.ui2
-rw-r--r--kexi/main/startup/KexiNewProjectWizard.cpp4
-rw-r--r--kexi/main/startup/KexiOpenExistingFile.ui4
-rw-r--r--kexi/main/startup/KexiProjectSelector.cpp2
-rw-r--r--kexi/main/startup/KexiProjectSelectorBase.ui2
-rw-r--r--kexi/main/startup/KexiStartup.cpp48
-rw-r--r--kexi/main/startup/KexiStartupDialogTemplatesPage.cpp4
-rw-r--r--kexi/main/startup/KexiStartupFileDialog.cpp6
-rw-r--r--kexi/main/startup/KexiStartupFileDialog_win.cpp10
-rw-r--r--kexi/main/startup/KexiStartup_p.cpp2
23 files changed, 135 insertions, 135 deletions
diff --git a/kexi/main/kexifinddialog.cpp b/kexi/main/kexifinddialog.cpp
index 0aa0cd35..b46eb20d 100644
--- a/kexi/main/kexifinddialog.cpp
+++ b/kexi/main/kexifinddialog.cpp
@@ -175,7 +175,7 @@ void KexiFindDialog::setCurrentLookInColumnName(const TQString& columnName)
index = d->lookInColumnNames.findIndex( columnName );
if (index == -1) {
kdWarning() << TQString("KexiFindDialog::setCurrentLookInColumn(%1) column name not found on the list")
- .tqarg(columnName) << endl;
+ .arg(columnName) << endl;
return;
}
index = index + 1/*"(All fields)"*/ + 1/*"(Current field)"*/;
@@ -214,13 +214,13 @@ void KexiFindDialog::setObjectNameForCaption(const TQString& name)
if (name.isEmpty())
setCaption(i18n("Replace"));
else
- setCaption(i18n("Replace in \"%1\"").tqarg(name));
+ setCaption(i18n("Replace in \"%1\"").arg(name));
}
else {
if (name.isEmpty())
setCaption(i18n("Find"));
else
- setCaption(i18n("Find in \"%1\"").tqarg(name));
+ setCaption(i18n("Find in \"%1\"").arg(name));
}
}
diff --git a/kexi/main/keximainwindowimpl.h b/kexi/main/keximainwindowimpl.h
index 5f3d887a..141cd475 100644
--- a/kexi/main/keximainwindowimpl.h
+++ b/kexi/main/keximainwindowimpl.h
@@ -346,7 +346,7 @@ class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUI
void slotPartLoaded(KexiPart::Part* p);
- void slotCaptionForCurrentMDIChild(bool tqchildrenMaximized);
+ void slotCaptionForCurrentMDIChild(bool childrenMaximized);
void slotNoMaximizedChildFrmLeft(KMdiChildFrm*);
void slotLastChildViewClosed();
void slotChildViewIsDetachedNow(TQWidget*);
diff --git a/kexi/main/keximainwindowimpl_p.h b/kexi/main/keximainwindowimpl_p.h
index 98600c62..b3d60b89 100644
--- a/kexi/main/keximainwindowimpl_p.h
+++ b/kexi/main/keximainwindowimpl_p.h
@@ -219,8 +219,8 @@ void updatePropEditorDockWidthInfo() {
void showStartProcessMsg(const TQStringList& args)
{
- wnd->showErrorMessage(i18n("Could not start %1 application.").tqarg(KEXI_APP_NAME),
- i18n("Command \"%1\" failed.").tqarg(args.join(" ")));
+ wnd->showErrorMessage(i18n("Could not start %1 application.").arg(KEXI_APP_NAME),
+ i18n("Command \"%1\" failed.").arg(args.join(" ")));
}
void hideMenuItem(const TQString& menuName, const TQString& itemText, bool alsoSeparator)
@@ -411,7 +411,7 @@ void updatePropEditorDockWidthInfo() {
}
KexiMainWindowImpl *wnd;
- KexiStatusBar *statusBar;
+ KexitStatusBar *statusBar;
KexiProject *prj;
KConfig *config;
#ifndef KEXI_NO_CTXT_HELP
diff --git a/kexi/main/kexinewstuff.cpp b/kexi/main/kexinewstuff.cpp
index 9beffbf5..1218df23 100644
--- a/kexi/main/kexinewstuff.cpp
+++ b/kexi/main/kexinewstuff.cpp
@@ -55,7 +55,7 @@ KexiNewStuff::install(const TQString &fileName)
KTar archive( fileName );
if ( !archive.open( IO_ReadOnly ) ) {
- kdDebug() << TQString("KexiNewStuff::install: Failed to open archivefile \"%1\"").tqarg(fileName) << endl;
+ kdDebug() << TQString("KexiNewStuff::install: Failed to open archivefile \"%1\"").arg(fileName) << endl;
return false;
}
const KArchiveDirectory *archiveDir = archive.directory();
diff --git a/kexi/main/kexistatusbar.h b/kexi/main/kexistatusbar.h
index e8c31d41..0d20e0a8 100644
--- a/kexi/main/kexistatusbar.h
+++ b/kexi/main/kexistatusbar.h
@@ -24,7 +24,7 @@
#define KEXISTATUSBAR_H
//temporary
-#define KexiStatusBar_KTEXTEDITOR_USED 0
+#define KexitStatusBar_KTEXTEDITOR_USED 0
#include <tdeversion.h>
#include <kstatusbar.h>
@@ -32,19 +32,19 @@
class TQLabel;
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
namespace KTextEditor { class ViewStatusMsgInterface; }
namespace KTextEditor { class ViewCursorInterface; }
#endif
namespace KParts { class Part; }
-class KexiStatusBar : public KStatusBar
+class KexitStatusBar : public KStatusBar
{
Q_OBJECT
TQ_OBJECT
public:
- KexiStatusBar( TQWidget *parent=0, const char *name=0 );
- virtual ~KexiStatusBar();
+ KexitStatusBar( TQWidget *parent=0, const char *name=0 );
+ virtual ~KexitStatusBar();
// virtual void addWidget( TQWidget *widget, int stretch = 0, bool permanent = false);
public slots:
@@ -60,7 +60,7 @@ class KexiStatusBar : public KStatusBar
int m_msgID, m_readOnlyID;
// TQLabel *m_status, *m_readOnlyStatus;
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
KTextEditor::ViewCursorInterface * m_cursorIface;
KTextEditor::ViewStatusMsgInterface * m_viewmsgIface;
#endif
diff --git a/kexi/main/printing/kexisimpleprintingengine.cpp b/kexi/main/printing/kexisimpleprintingengine.cpp
index ac829ce1..3e6f8a97 100644
--- a/kexi/main/printing/kexisimpleprintingengine.cpp
+++ b/kexi/main/printing/kexisimpleprintingengine.cpp
@@ -326,9 +326,9 @@ void KexiSimplePrintingEngine::paintPage(int pageNumber, TQPainter& painter, boo
TQString pageNumString;
if (m_pagesCount>0)
pageNumString = i18n("Page (number) of (total)", "Page %1 of %2")
- .tqarg(pageNumber+1).tqarg(m_pagesCount);
+ .arg(pageNumber+1).arg(m_pagesCount);
else
- pageNumString = i18n("Page %1").tqarg(pageNumber+1);
+ pageNumString = i18n("Page %1").arg(pageNumber+1);
painter.drawText((int)m_leftMargin,
(int)m_topMargin + m_pageHeight - m_mainLineSpacing,
m_pageWidth, m_mainLineSpacing,
diff --git a/kexi/main/printing/kexisimpleprintingpagesetup.cpp b/kexi/main/printing/kexisimpleprintingpagesetup.cpp
index 476f924a..c536f676 100644
--- a/kexi/main/printing/kexisimpleprintingpagesetup.cpp
+++ b/kexi/main/printing/kexisimpleprintingpagesetup.cpp
@@ -356,7 +356,7 @@ KexiSimplePrintingPageSetup::KexiSimplePrintingPageSetup( KexiMainWindow *mainWi
m_contents->openDataLink->setText( i18n("Open This Query") );
m_origCaptionLabelText = i18n("<h2>Page setup for printing \"%1\" query data</h2>");
}
- m_contents->captionLabel->setText( m_origCaptionLabelText.tqarg(m_item->name()) );
+ m_contents->captionLabel->setText( m_origCaptionLabelText.arg(m_item->name()) );
}
connect(m_contents->headerTitleLineEdit,TQT_SIGNAL(textChanged(const TQString&)),
this, TQT_SLOT(slotTitleTextChanged(const TQString&)));
@@ -442,8 +442,8 @@ void KexiSimplePrintingPageSetup::updatePageLayoutAndUnitInfo()
TQString s;
if (m_settings.pageLayout.format == PG_CUSTOM) {
s += TQString(" (%1 %2 x %3 %4)")
- .tqarg(m_settings.pageLayout.ptWidth).tqarg(KoUnit::unitName(m_unit))
- .tqarg(m_settings.pageLayout.ptHeight).tqarg(KoUnit::unitName(m_unit));
+ .arg(m_settings.pageLayout.ptWidth).arg(KoUnit::unitName(m_unit))
+ .arg(m_settings.pageLayout.ptHeight).arg(KoUnit::unitName(m_unit));
}
else
s += KoPageFormat::name(m_settings.pageLayout.format);
diff --git a/kexi/main/printing/kexisimpleprintingpagesetupbase.ui b/kexi/main/printing/kexisimpleprintingpagesetupbase.ui
index de57e97e..4bf6deec 100644
--- a/kexi/main/printing/kexisimpleprintingpagesetupbase.ui
+++ b/kexi/main/printing/kexisimpleprintingpagesetupbase.ui
@@ -45,7 +45,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
@@ -106,7 +106,7 @@
<property name="text">
<string>Page title:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignBottom</set>
</property>
<property name="buddy" stdset="0">
diff --git a/kexi/main/printing/kexisimpleprintpreviewwindow.cpp b/kexi/main/printing/kexisimpleprintpreviewwindow.cpp
index f07722d8..83d9cb06 100644
--- a/kexi/main/printing/kexisimpleprintpreviewwindow.cpp
+++ b/kexi/main/printing/kexisimpleprintpreviewwindow.cpp
@@ -52,7 +52,7 @@ void KexiSimplePrintPreviewView::paintEvent( TQPaintEvent *pe )
return;
TQPixmap pm(size()); //dbl buffered
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(&pm), this);
+ p.begin(TQT_TQPAINTDEVICE(&pm), this);
//! @todo only for screen!
p.fillRect(TQRect(TQPoint(0,0),pm.size()), TQBrush(white));//pe->rect(), TQBrush(white));
if (m_window->currentPage()>=0)
@@ -135,7 +135,7 @@ void KexiSimplePrintPreviewScrollView::setFullWidth()
viewport()->setUpdatesEnabled(true);
resize(size()+TQSize(1,1)); //to update pos.
widget->enablePainting = true;
- widget->tqrepaint();
+ widget->repaint();
}
void KexiSimplePrintPreviewScrollView::setContentsPos(int x, int y)
@@ -157,7 +157,7 @@ KexiSimplePrintPreviewWindow::KexiSimplePrintPreviewWindow(
, m_pageNumber(-1)
, m_pagesCount(-1)
{
- setCaption(i18n("%1 - Print Preview - %2").tqarg(previewName).tqarg(KEXI_APP_NAME));
+ setCaption(i18n("%1 - Print Preview - %2").arg(previewName).arg(KEXI_APP_NAME));
setIcon(DesktopIcon("filequickprint"));
TQVBoxLayout *lyr = new TQVBoxLayout(this, 6);
@@ -308,14 +308,14 @@ void KexiSimplePrintPreviewWindow::goToPage(int pageNumber)
m_pageNumber = pageNumber;
m_pagesCount = m_engine.pagesCount();
- m_view->tqrepaint(); //this will automatically paint a new page
+ m_view->repaint(); //this will automatically paint a new page
m_navToolbar->setItemEnabled(m_idNext, pageNumber < ((int)m_engine.pagesCount()-1));
m_navToolbar->setItemEnabled(m_idLast, pageNumber < ((int)m_engine.pagesCount()-1));
m_navToolbar->setItemEnabled(m_idPrevious, pageNumber > 0);
m_navToolbar->setItemEnabled(m_idFirst, pageNumber > 0);
static_cast<TQLabel*>(m_navToolbar->getWidget(m_idPageNumberLabel))->setText(
- i18n("Page (number) of (total)", "Page %1 of %2").tqarg(m_pageNumber+1).tqarg(m_engine.pagesCount()));
+ i18n("Page (number) of (total)", "Page %1 of %2").arg(m_pageNumber+1).arg(m_engine.pagesCount()));
}
void KexiSimplePrintPreviewWindow::setFullWidth()
diff --git a/kexi/main/startup/KexiConnSelector.cpp b/kexi/main/startup/KexiConnSelector.cpp
index a9a2a316..60e98852 100644
--- a/kexi/main/startup/KexiConnSelector.cpp
+++ b/kexi/main/startup/KexiConnSelector.cpp
@@ -350,9 +350,9 @@ bool KexiConnSelectorWidget::confirmOverwrites() const
/*static TQString msgUnfinished() {
return i18n("To define or change a connection, use command line options or click on .kexis file. "
- "You can find example .kexis file at <a href=\"%1\">here</a>.").tqarg("") //temporary, please do not change for 0.8!
+ "You can find example .kexis file at <a href=\"%1\">here</a>.").arg("") //temporary, please do not change for 0.8!
+ "\nhttp://www.kexi-project.org/resources/testdb.kexis"; */
-// .tqarg("http://websvn.kde.org/*checkout*/branches/kexi/0.9/koffice/kexi/tests/startup/testdb.kexis");
+// .arg("http://websvn.kde.org/*checkout*/branches/kexi/0.9/koffice/kexi/tests/startup/testdb.kexis");
//}
void KexiConnSelectorWidget::slotRemoteAddBtnClicked()
@@ -407,7 +407,7 @@ void KexiConnSelectorWidget::slotRemoteRemoveBtnClicked()
return;
if (KMessageBox::Continue!=KMessageBox::warningContinueCancel(0,
i18n("Do you want to remove database connection \"%1\" from the list of available connections?")
- .tqarg(item->data()->serverInfoString(true)), TQString(), KStdGuiItem::del(), TQString(),
+ .arg(item->data()->serverInfoString(true)), TQString(), KStdGuiItem::del(), TQString(),
KMessageBox::Notify|KMessageBox::Dangerous))
return;
diff --git a/kexi/main/startup/KexiConnSelectorBase.ui b/kexi/main/startup/KexiConnSelectorBase.ui
index 4c371ed2..c55614e2 100644
--- a/kexi/main/startup/KexiConnSelectorBase.ui
+++ b/kexi/main/startup/KexiConnSelectorBase.ui
@@ -246,7 +246,7 @@
&lt;p&gt;You will see existing Kexi projects available for the selected connection. Here you may also add, edit or remove connections from the list.
</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
<property name="buddy" stdset="0">
@@ -268,7 +268,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
</widget>
diff --git a/kexi/main/startup/KexiNewPrjTypeSelector.ui b/kexi/main/startup/KexiNewPrjTypeSelector.ui
index 29e52812..122137e1 100644
--- a/kexi/main/startup/KexiNewPrjTypeSelector.ui
+++ b/kexi/main/startup/KexiNewPrjTypeSelector.ui
@@ -74,7 +74,7 @@
<string>Kexi will create a new database project. Select a storage method which will be used to store the new project.
</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
diff --git a/kexi/main/startup/KexiNewProjectWizard.cpp b/kexi/main/startup/KexiNewProjectWizard.cpp
index 625af34f..0e7f872a 100644
--- a/kexi/main/startup/KexiNewProjectWizard.cpp
+++ b/kexi/main/startup/KexiNewProjectWizard.cpp
@@ -301,7 +301,7 @@ void KexiNewProjectWizard::next()
return;
}
m_project_selector->label->setText(
- d->server_db_name_dblist_lbl_txt.tqarg(m_conn_sel->selectedConnectionData()->serverInfoString(false)) );
+ d->server_db_name_dblist_lbl_txt.arg(m_conn_sel->selectedConnectionData()->serverInfoString(false)) );
m_server_db_name->le_caption->setFocus();
}
@@ -342,7 +342,7 @@ void KexiNewProjectWizard::accept()
if (KMessageBox::Continue!=KMessageBox::warningContinueCancel( this, "<qt>"
+i18n("<b>A project with database name \"%1\" already exists</b>"
"<p>Do you want to delete it and create a new one?")
- .tqarg( m_server_db_name->le_dbname->text() ), TQString(), KStdGuiItem::del(),
+ .arg( m_server_db_name->le_dbname->text() ), TQString(), KStdGuiItem::del(),
TQString(), KMessageBox::Notify|KMessageBox::Dangerous ))
{
m_server_db_name->le_dbname->setFocus();
diff --git a/kexi/main/startup/KexiOpenExistingFile.ui b/kexi/main/startup/KexiOpenExistingFile.ui
index b822f0ff..2f778429 100644
--- a/kexi/main/startup/KexiOpenExistingFile.ui
+++ b/kexi/main/startup/KexiOpenExistingFile.ui
@@ -35,7 +35,7 @@
<string>&lt;b&gt;Select existing Kexi project file to open:&lt;/b&gt;
</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
@@ -112,7 +112,7 @@
<property name="text">
<string>Click "Advanced" button if you want to find an existing project on a server rather than a file.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
diff --git a/kexi/main/startup/KexiProjectSelector.cpp b/kexi/main/startup/KexiProjectSelector.cpp
index 9353e3a6..878e0273 100644
--- a/kexi/main/startup/KexiProjectSelector.cpp
+++ b/kexi/main/startup/KexiProjectSelector.cpp
@@ -248,7 +248,7 @@ KexiProjectSelectorDialog::KexiProjectSelectorDialog( TQWidget *parent, const ch
init(prj_set, showProjectNameColumn, showConnectionColumns);
m_sel->label->setText( i18n("Select a project on <b>%1</b> database server to open:")
- .tqarg(cdata->serverInfoString(false)) );
+ .arg(cdata->serverInfoString(false)) );
}
KexiProjectSelectorDialog::~KexiProjectSelectorDialog()
diff --git a/kexi/main/startup/KexiProjectSelectorBase.ui b/kexi/main/startup/KexiProjectSelectorBase.ui
index 57aa28ad..5159d9bb 100644
--- a/kexi/main/startup/KexiProjectSelectorBase.ui
+++ b/kexi/main/startup/KexiProjectSelectorBase.ui
@@ -43,7 +43,7 @@
<string>&lt;b&gt;There are Kexi projects you have recently opened.&lt;/b&gt; Select one you wish to open:
</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
diff --git a/kexi/main/startup/KexiStartup.cpp b/kexi/main/startup/KexiStartup.cpp
index 1708efbc..17afbc7d 100644
--- a/kexi/main/startup/KexiStartup.cpp
+++ b/kexi/main/startup/KexiStartup.cpp
@@ -144,13 +144,13 @@ KexiDBPasswordDialog::KexiDBPasswordDialog(TQWidget *parent, KexiDB::ConnectionD
+ i18n("Please enter the password.") + "</p>";
/* msg += cdata.userName.isEmpty() ?
"<p>"+i18n("Please enter the password.")
- : "<p>"+i18n("Please enter the password for user.").tqarg("<b>"+cdata.userName+"</b>");*/
+ : "<p>"+i18n("Please enter the password for user.").arg("<b>"+cdata.userName+"</b>");*/
TQString srv = cdata.serverInfoString(false);
if (srv.isEmpty() || srv.lower()=="localhost")
srv = i18n("local database server");
- msg += ("</p><p>"+i18n("Database server: %1").tqarg(TQString("<nobr>")+srv+"</nobr>")+"</p>");
+ msg += ("</p><p>"+i18n("Database server: %1").arg(TQString("<nobr>")+srv+"</nobr>")+"</p>");
TQString usr;
if (cdata.userName.isEmpty())
@@ -158,7 +158,7 @@ KexiDBPasswordDialog::KexiDBPasswordDialog(TQWidget *parent, KexiDB::ConnectionD
else
usr = cdata.userName;
- msg += ("<p>"+i18n("Username: %1").tqarg(usr)+"</p>");
+ msg += ("<p>"+i18n("Username: %1").arg(usr)+"</p>");
setPrompt( msg );
if (showDetailsButton) {
@@ -283,7 +283,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
KMessageBox::sorry( 0, "<qt>"
+i18n("Could not read connection information from connection shortcut "
"file <nobr>\"%1\"</nobr>.<br><br>Check whether the file has valid contents.")
- .tqarg(TQDir::convertSeparators(connectionShortcut.fileName())));
+ .arg(TQDir::convertSeparators(connectionShortcut.fileName())));
return false;
}
}
@@ -295,7 +295,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
if (args->count()>0 && (!fileType.isEmpty() && fileType!="project" && fileType!="shortcut" && fileType!="connection")) {
KMessageBox::sorry( 0,
i18n("You have specified invalid argument (\"%1\") for \"type\" command-line option.")
- .tqarg(fileType));
+ .arg(fileType));
return false;
}
@@ -434,7 +434,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
if (dropDB && !projectFileExists) {
KMessageBox::sorry(0,
i18n("Could not remove project.\nThe file \"%1\" does not exist.")
- .tqarg(TQDir::convertSeparators(cdata.dbFileName())));
+ .arg(TQDir::convertSeparators(cdata.dbFileName())));
return 0;
}
}
@@ -476,7 +476,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
m_projectData = new KexiProjectData();
if (!d->shortcutFile->loadProjectData(*m_projectData, &d->shortcutFileGroupKey)) {
KMessageBox::sorry(0, i18n("Could not open shortcut file\n\"%1\".")
- .tqarg(TQDir::convertSeparators(cdata.fileName())));
+ .arg(TQDir::convertSeparators(cdata.fileName())));
delete m_projectData;
m_projectData = 0;
delete d->shortcutFile;
@@ -509,7 +509,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
d->connShortcutFile = new KexiDBConnShortcutFile(cdata.fileName());
if (!d->connShortcutFile->loadConnectionData(cdata, &d->shortcutFileGroupKey)) {
KMessageBox::sorry(0, i18n("Could not open connection data file\n\"%1\".")
- .tqarg(TQDir::convertSeparators(cdata.fileName())));
+ .arg(TQDir::convertSeparators(cdata.fileName())));
delete d->connShortcutFile;
d->connShortcutFile = 0;
return false;
@@ -612,7 +612,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
if (!alsoOpenDB) {
if (ok) {
KMessageBox::information( 0, i18n("Project \"%1\" created successfully.")
- .tqarg( TQDir::convertSeparators(projectData()->databaseName()) ));
+ .arg( TQDir::convertSeparators(projectData()->databaseName()) ));
}
return ok;
}
@@ -622,7 +622,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
tristate res = KexiProject::dropProject(projectData(), &gui, false/*ask*/);
if (res==true)
KMessageBox::information( 0, i18n("Project \"%1\" dropped successfully.")
- .tqarg( TQDir::convertSeparators(projectData()->databaseName()) ));
+ .arg( TQDir::convertSeparators(projectData()->databaseName()) ));
return res!=false;
}
@@ -749,7 +749,7 @@ tristate KexiStartupHandler::detectActionForFile(
if (!(options & SkipMessages))
KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
+i18n("<p>The file <nobr>\"%1\"</nobr> does not exist or is not readable.</p>")
- .tqarg(TQDir::convertSeparators(dbFileName))
+ .arg(TQDir::convertSeparators(dbFileName))
+i18n("Check the file's permissions and whether it is already opened "
"and locked by another application."));
return false;
@@ -781,7 +781,7 @@ tristate KexiStartupHandler::detectActionForFile(
if (!(options & SkipMessages))
KMessageBox::sorry(parent, i18n("<p>Could not open project.</p>")
+i18n("<p>The file <nobr>\"%1\"</nobr> is not readable.</p>")
- .tqarg(TQDir::convertSeparators(dbFileName))
+ .arg(TQDir::convertSeparators(dbFileName))
+i18n("Check the file's permissions and whether it is already opened "
"and locked by another application."));
return false;
@@ -804,7 +804,7 @@ tristate KexiStartupHandler::detectActionForFile(
if ((options & SkipMessages) || KMessageBox::Yes != KMessageBox::questionYesNo(
parent, i18n("\"%1\" is an external file of type:\n\"%2\".\n"
"Do you want to import the file as a Kexi project?")
- .tqarg(TQDir::convertSeparators(dbFileName)).tqarg(ptr.data()->comment()),
+ .arg(TQDir::convertSeparators(dbFileName)).arg(ptr.data()->comment()),
i18n("Open External File"), KGuiItem(i18n("Import...")), KStdGuiItem::cancel() ) )
{
return cancelled;
@@ -830,8 +830,8 @@ tristate KexiStartupHandler::detectActionForFile(
"The project file \"%1\" is recognized as compatible with \"%2\" database driver, "
"while you have asked for \"%3\" database driver to be used.\n"
"Do you want to use \"%4\" database driver?")
- .tqarg(TQDir::convertSeparators(dbFileName))
- .tqarg(tmpDriverName).tqarg(suggestedDriverName).tqarg(tmpDriverName));
+ .arg(TQDir::convertSeparators(dbFileName))
+ .arg(tmpDriverName).arg(suggestedDriverName).arg(tmpDriverName));
if (KMessageBox::Yes == res)
useDetectedDriver = true;
else if (KMessageBox::Cancel == res)
@@ -851,7 +851,7 @@ tristate KexiStartupHandler::detectActionForFile(
&& KMessageBox::Yes == KMessageBox::questionYesNo(parent, i18n(
"Previous version of database file format (\"%1\") is detected in the \"%2\" "
"project file.\nDo you want to convert the project to a new \"%3\" format (recommended)?")
- .tqarg(detectedDriverName).tqarg(TQDir::convertSeparators(dbFileName)).tqarg(newFileFormat)) )
+ .arg(detectedDriverName).arg(TQDir::convertSeparators(dbFileName)).arg(newFileFormat)) )
{
// SQLite2ToSQLite3Migration *migr = new
SQLite2ToSQLite3Migration migr( finfo.absFilePath() );
@@ -862,7 +862,7 @@ tristate KexiStartupHandler::detectActionForFile(
KMessageBox::sorry(parent, i18n(
"Failed to convert project file \"%1\" to a new \"%2\" format.\n"
"The file format remains unchanged.")
- .tqarg(TQDir::convertSeparators(dbFileName)).tqarg(newFileFormat) );
+ .arg(TQDir::convertSeparators(dbFileName)).arg(newFileFormat) );
//continue...
}
if (res==true)
@@ -878,12 +878,12 @@ tristate KexiStartupHandler::detectActionForFile(
if (!(options & SkipMessages))
KMessageBox::detailedSorry(parent,
i18n( "The file \"%1\" is not recognized as being supported by Kexi.")
- .tqarg(TQDir::convertSeparators(dbFileName)),
+ .arg(TQDir::convertSeparators(dbFileName)),
TQString::fromLatin1("<p>")
+i18n("Database driver for this file type not found.\nDetected MIME type: %1")
- .tqarg(mimename)
+ .arg(mimename)
+(ptr.data()->comment().isEmpty()
- ? TQString::fromLatin1(".") : TQString::fromLatin1(" (%1).").tqarg(ptr.data()->comment()))
+ ? TQString::fromLatin1(".") : TQString::fromLatin1(" (%1).").arg(ptr.data()->comment()))
+TQString::fromLatin1("</p>")
+possibleProblemsInfoMsg);
return false;
@@ -917,13 +917,13 @@ KexiStartupHandler::selectProject(KexiDB::ConnectionData *cdata, bool& cancelled
if (prjdlg.projectSet())
msgh.showErrorMessage(prjdlg.projectSet(),
i18n("Could not load list of available projects for <b>%1</b> database server.")
- .tqarg(cdata->serverInfoString(true)));
+ .arg(cdata->serverInfoString(true)));
else
msgh.showErrorMessage(
i18n("Could not load list of available projects for <b>%1</b> database server.")
- .tqarg(cdata->serverInfoString(true)));
+ .arg(cdata->serverInfoString(true)));
// setStatus(i18n("Could not load list of available projects for database server \"%1\"")
-// .tqarg(cdata->serverInfoString(true)), prjdlg.projectSet()->errorMsg());
+// .arg(cdata->serverInfoString(true)), prjdlg.projectSet()->errorMsg());
return 0;
}
if (prjdlg.exec()!=TQDialog::Accepted) {
@@ -952,7 +952,7 @@ void KexiStartupHandler::slotSaveShortcutFileChanges()
if (!ok) {
KMessageBox::sorry(0, i18n("Failed saving connection data to\n\"%1\" file.")
- .tqarg(TQDir::convertSeparators(d->shortcutFile->fileName())));
+ .arg(TQDir::convertSeparators(d->shortcutFile->fileName())));
}
}
diff --git a/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp b/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
index 429499f4..d919463d 100644
--- a/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
+++ b/kexi/main/startup/KexiStartupDialogTemplatesPage.cpp
@@ -123,8 +123,8 @@ void TemplatesPage::itemClicked(TQIconViewItem *item) {
return;
}
TQString t = TQString("<h2>%1</h2><p>%2</p>")
- .tqarg(static_cast<TemplateItem*>(item)->name)
- .tqarg(static_cast<TemplateItem*>(item)->description);
+ .arg(static_cast<TemplateItem*>(item)->name)
+ .arg(static_cast<TemplateItem*>(item)->description);
#ifndef DB_TEMPLATES
t += TQString("<p>") + i18n("We are sorry, templates are not yet available.") +"</p>";
#endif
diff --git a/kexi/main/startup/KexiStartupFileDialog.cpp b/kexi/main/startup/KexiStartupFileDialog.cpp
index 1e50a12d..72db4af2 100644
--- a/kexi/main/startup/KexiStartupFileDialog.cpp
+++ b/kexi/main/startup/KexiStartupFileDialog.cpp
@@ -300,7 +300,7 @@ bool KexiStartupFileDialog::checkFileName()
if (mode() & KFile::ExistingOnly) {
if ( !fi.exists() ) {
KMessageBox::error( this, "<qt>"+i18n( "The file \"%1\" does not exist." )
- .tqarg( TQDir::convertSeparators(path) ) );
+ .arg( TQDir::convertSeparators(path) ) );
return false;
}
else if (mode() & KFile::File) {
@@ -310,7 +310,7 @@ bool KexiStartupFileDialog::checkFileName()
}
else if (!fi.isReadable()) {
KMessageBox::error( this, "<qt>"+i18n( "The file \"%1\" is not readable." )
- .tqarg( TQDir::convertSeparators(path) ) );
+ .arg( TQDir::convertSeparators(path) ) );
return false;
}
}
@@ -329,7 +329,7 @@ bool KexiStartupFileDialog::askForOverwriting(const TQString& filePath, TQWidget
if (!fi.exists())
return true;
const int res = KMessageBox::warningYesNo( parent, i18n( "The file \"%1\" already exists.\n"
- "Do you want to overwrite it?").tqarg( TQDir::convertSeparators(filePath) ), TQString(),
+ "Do you want to overwrite it?").arg( TQDir::convertSeparators(filePath) ), TQString(),
i18n("Overwrite"), KStdGuiItem::no() );
if (res == KMessageBox::Yes)
return true;
diff --git a/kexi/main/startup/KexiStartupFileDialog_win.cpp b/kexi/main/startup/KexiStartupFileDialog_win.cpp
index 67a44ca6..36b8c527 100644
--- a/kexi/main/startup/KexiStartupFileDialog_win.cpp
+++ b/kexi/main/startup/KexiStartupFileDialog_win.cpp
@@ -120,27 +120,27 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
/*
KURL u;
u.setPath( TQDir::rootDirPath() );
- TQString text = i18n("Root Directory: %1").tqarg( u.path() );
+ TQString text = i18n("Root Directory: %1").arg( u.path() );
d->pathCombo->addDefaultURL( u,
KMimeType::pixmapForURL( u, 0, KIcon::Small ),
text );
u.setPath( TQDir::homeDirPath() );
- text = i18n("Home Directory: %1").tqarg( u.path( +1 ) );
+ text = i18n("Home Directory: %1").arg( u.path( +1 ) );
d->pathCombo->addDefaultURL( u, KMimeType::pixmapForURL( u, 0, KIcon::Small ),
text );
KURL docPath;
docPath.setPath( KGlobalSettings::documentPath() );
if ( u.path(+1) != docPath.path(+1) ) {
- text = i18n("Documents: %1").tqarg( docPath.path( +1 ) );
+ text = i18n("Documents: %1").arg( docPath.path( +1 ) );
d->pathCombo->addDefaultURL( u,
KMimeType::pixmapForURL( u, 0, KIcon::Small ),
text );
}
u.setPath( KGlobalSettings::desktopPath() );
- text = i18n("Desktop: %1").tqarg( u.path( +1 ) );
+ text = i18n("Desktop: %1").arg( u.path( +1 ) );
d->pathCombo->addDefaultURL( u,
KMimeType::pixmapForURL( u, 0, KIcon::Small ),
text );
@@ -185,7 +185,7 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
coll->action( "up" )->plug( toolbar );
coll->action( "up" )->setWhatsThis(i18n("<qt>Click this button to enter the parent directory.<p>"
"For instance, if the current location is file:/home/%1 clicking this "
- "button will take you to file:/home.</qt>").tqarg(getlogin()));
+ "button will take you to file:/home.</qt>").arg(getlogin()));
coll->action( "back" )->plug( toolbar );
coll->action( "back" )->setWhatsThis(i18n("Click this button to move backwards one step in the browsing history."));
coll->action( "forward" )->plug( toolbar );
diff --git a/kexi/main/startup/KexiStartup_p.cpp b/kexi/main/startup/KexiStartup_p.cpp
index e8139e18..e959ccdc 100644
--- a/kexi/main/startup/KexiStartup_p.cpp
+++ b/kexi/main/startup/KexiStartup_p.cpp
@@ -73,7 +73,7 @@ tristate SQLite2ToSQLite3Migration::run()
m_dlg = new KProgressDialog(0, 0, TQString(),
i18n("Saving \"%1\" project file to a new \"%2\" database format...")
- .tqarg(TQDir::convertSeparators(TQFileInfo(m_filePath).fileName())).tqarg("SQLite3")
+ .arg(TQDir::convertSeparators(TQFileInfo(m_filePath).fileName())).arg("SQLite3")
);
m_dlg->setModal(true);
connect(m_dlg, TQT_SIGNAL(cancelClicked()), this, TQT_SLOT(cancelClicked()));
diff --git a/kexi/main/keximainwindowimpl.cpp b/kexi/main/keximainwindowimpl.cpp
index 293271c5..dc7fc428 100644
--- a/kexi/main/keximainwindowimpl.cpp
+++ b/kexi/main/keximainwindowimpl.cpp
@@ -111,7 +111,7 @@
# define KexiVDebug if (0) kdDebug()
#endif
//first fix the tqgeometry
//#define KEXI_NO_CTXT_HELP 1
#ifndef KEXI_NO_CTXT_HELP
@@ -245,8 +245,8 @@ KexiMainWindowImpl::KexiMainWindowImpl()
int scnum = TQApplication::desktop()->screenNumber(parentWidget());
TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
d->config->setGroup("MainWindow");
- TQSize s ( d->config->readNumEntry( TQString::fromLatin1("Width %1").tqarg(desk.width()), 700 ),
- d->config->readNumEntry( TQString::fromLatin1("Height %1").tqarg(desk.height()), 480 ) );
+ TQSize s ( d->config->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 700 ),
+ d->config->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 480 ) );
resize (kMin (s.width(), desk.width()), kMin(s.height(), desk.height()));
}
@@ -277,7 +277,7 @@ KexiMainWindowImpl::KexiMainWindowImpl()
createShellGUI(true);
//}
- d->statusBar = new KexiStatusBar(this, "status_bar");
+ d->statusBar = new KexitStatusBar(this, "status_bar");
d->origAppCaption = caption();
@@ -465,7 +465,7 @@ void KexiMainWindowImpl::switchToIDEAlMode(bool showMessage)
else {
KMessageBox::information(this,
i18n("User interface mode will be switched to IDEAl at next %1 application startup.")
- .tqarg(KEXI_APP_NAME));
+ .arg(KEXI_APP_NAME));
//delayed
d->mdiModeToSwitchAfterRestart = KMdi::IDEAlMode;
}
@@ -492,7 +492,7 @@ void KexiMainWindowImpl::switchToChildframeMode(bool showMessage)
else {
KMessageBox::information(this,
i18n("User interface mode will be switched to Childframe at next %1 application startup.")
- .tqarg(KEXI_APP_NAME));
+ .arg(KEXI_APP_NAME));
//delayed
d->mdiModeToSwitchAfterRestart = KMdi::ChildframeMode;
}
@@ -1281,7 +1281,7 @@ static TQString internalReason(KexiDB::Object *obj)
const TQString &s = obj->errorMsg();
if (s.isEmpty())
return s;
- return TQString("<br>(%1) ").tqarg(i18n("reason:")+" <i>"+s+"</i>");
+ return TQString("<br>(%1) ").arg(i18n("reason:")+" <i>"+s+"</i>");
}
tristate KexiMainWindowImpl::openProject(const KexiProjectData& projectData)
@@ -1319,7 +1319,7 @@ tristate KexiMainWindowImpl::openProject(const KexiProjectData& projectData)
if (incompatibleWithKexi) {
if (KMessageBox::Yes == KMessageBox::questionYesNo(this,
i18n("<qt>Database project %1 does not appear to have been created using Kexi.<br><br>"
- "Do you want to import it as a new Kexi project?</qt>").tqarg(projectData.infoString()),
+ "Do you want to import it as a new Kexi project?</qt>").arg(projectData.infoString()),
0, KGuiItem(i18n("Import Database", "&Import..."), "database_import"),
KStdGuiItem::quit()))
{
@@ -1447,9 +1447,9 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
not_found_msg += (TQString("\"") + info["name"] + "\" - ");
if (info["action"]=="new")
not_found_msg += i18n("cannot create object - unknown object type \"%1\"")
- .tqarg(info["type"]);
+ .arg(info["type"]);
else
- not_found_msg += i18n("unknown object type \"%1\"").tqarg(info["type"]);
+ not_found_msg += i18n("unknown object type \"%1\"").arg(info["type"]);
not_found_msg += internalReason(&Kexi::partManager())+"<br></li>";
continue;
}
@@ -1457,7 +1457,7 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
if (info["action"]=="new") {
if (!newObject( i, openingCancelled) && !openingCancelled) {
not_found_msg += "<li>";
- not_found_msg += (i18n("cannot create object of type \"%1\"").tqarg(info["type"])+
+ not_found_msg += (i18n("cannot create object of type \"%1\"").arg(info["type"])+
internalReason(d->prj)+"<br></li>");
}
else
@@ -1551,7 +1551,7 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
if (!not_found_msg.isEmpty())
showErrorMessage(i18n("You have requested selected objects to be automatically opened "
"or processed on startup. Several objects cannot be opened or processed."),
- TQString("<ul>%1</ul>").tqarg(not_found_msg) );
+ TQString("<ul>%1</ul>").arg(not_found_msg) );
d->updatePropEditorVisibility(d->curDialog ? d->curDialog->currentViewMode() : 0);
#if defined(KDOCKWIDGET_P)
@@ -1864,7 +1864,7 @@ void KexiMainWindowImpl::slotPartLoaded(KexiPart::Part* p)
}
//! internal
-void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool tqchildrenMaximized)
+void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool childrenMaximized)
{
//js todo: allow to set custom "static" app caption
@@ -1877,13 +1877,13 @@ void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool tqchildrenMaximized)
//current dialog isn't attached! - find top level child
if (m_pMdi->topChild()) {
view = m_pMdi->topChild()->m_pClient;
- tqchildrenMaximized = view->mdiParent()->state()==KMdiChildFrm::Maximized;
+ childrenMaximized = view->mdiParent()->state()==KMdiChildFrm::Maximized;
}
else
view = 0;
}
- if (tqchildrenMaximized && view) {
+ if (childrenMaximized && view) {
setCaption( d->curDialog->caption()
+ (d->appCaptionPrefix.isEmpty() ? TQString() : (TQString::fromLatin1(" - ") + d->appCaptionPrefix)) );
}
@@ -2093,8 +2093,8 @@ KexiMainWindowImpl::restoreSettings()
}*/
config->setGroup("MainWindow");
- TQSize s ( config->readNumEntry( TQString::fromLatin1("Width %1").tqarg(desk.width()), 700 ),
- config->readNumEntry( TQString::fromLatin1("Height %1").tqarg(desk.height()), 480 ) );
+ TQSize s ( config->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 700 ),
+ config->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 480 ) );
resize (kMin (s.width(), desk.width()), kMin(s.height(), desk.height()));
}
#endif
@@ -3006,10 +3006,10 @@ bool KexiMainWindowImpl::switchToViewMode(int viewMode)
}
if (!d->curDialog->supportsViewMode( viewMode )) {
showErrorMessage(i18n("Selected view is not supported for \"%1\" object.")
- .tqarg(d->curDialog->partItem()->name()),
+ .arg(d->curDialog->partItem()->name()),
i18n("Selected view (%1) is not supported by this object type (%2).")
- .tqarg(Kexi::nameForViewMode(viewMode))
- .tqarg(d->curDialog->part()->instanceCaption()) );
+ .arg(Kexi::nameForViewMode(viewMode))
+ .arg(d->curDialog->part()->instanceCaption()) );
d->toggleLastCheckedMode();
return false;
}
@@ -3019,7 +3019,7 @@ bool KexiMainWindowImpl::switchToViewMode(int viewMode)
tristate res = d->curDialog->switchToViewMode( viewMode );
if (!res) {
updateCustomPropertyPanelTabs(0, Kexi::NoViewMode); //revert
- showErrorMessage(i18n("Switching to other view failed (%1).").tqarg(Kexi::nameForViewMode(viewMode)),
+ showErrorMessage(i18n("Switching to other view failed (%1).").arg(Kexi::nameForViewMode(viewMode)),
d->curDialog);
d->toggleLastCheckedMode();
return false;
@@ -3118,7 +3118,7 @@ tristate KexiMainWindowImpl::getNewObjectInfo(
if (allowOverwriting) {
int res = KMessageBox::warningYesNoCancel(this,
"<p>"+part->i18nMessage("Object \"%1\" already exists.", 0)
- .tqarg(d->nameDialog->widget()->nameText())
+ .arg(d->nameDialog->widget()->nameText())
+"</p><p>"+i18n("Do you want to replace it?")+"</p>", 0,
KGuiItem(i18n("&Replace"), "button_yes"),
KGuiItem(i18n("&Choose Other Name...")),
@@ -3135,11 +3135,11 @@ tristate KexiMainWindowImpl::getNewObjectInfo(
else {
KMessageBox::information(this,
"<p>"+part->i18nMessage("Object \"%1\" already exists.", 0)
- .tqarg(d->nameDialog->widget()->nameText())
+ .arg(d->nameDialog->widget()->nameText())
+"</p><p>"+i18n("Please choose other name.")+"</p>");
// " For example: Table \"my_table\" already exists" ,
// "%1 \"%2\" already exists.\nPlease choose other name.")
-// .tqarg(dlg->part()->instanceName()).tqarg(d->nameDialog->widget()->nameText()));
+// .arg(dlg->part()->instanceName()).arg(d->nameDialog->widget()->nameText()));
continue;
}
}
@@ -3160,7 +3160,7 @@ tristate KexiMainWindowImpl::saveObject( KexiDialogBase *dlg, const TQString& me
//data was saved in the past -just save again
res = dlg->storeData(dontAsk);
if (!res)
- showErrorMessage(i18n("Saving \"%1\" object failed.").tqarg(dlg->partItem()->name()),
+ showErrorMessage(i18n("Saving \"%1\" object failed.").arg(dlg->partItem()->name()),
d->curDialog);
return res;
}
@@ -3177,7 +3177,7 @@ tristate KexiMainWindowImpl::saveObject( KexiDialogBase *dlg, const TQString& me
if (~res)
return cancelled;
if (!res) {
- showErrorMessage(i18n("Saving new \"%1\" object failed.").tqarg(dlg->partItem()->name()),
+ showErrorMessage(i18n("Saving new \"%1\" object failed.").arg(dlg->partItem()->name()),
d->curDialog);
return false;
}
@@ -3224,11 +3224,11 @@ tristate KexiMainWindowImpl::closeDialog(KexiDialogBase *dlg, bool layoutTaskBar
saveChanges.setToolTip(i18n("Save changes"));
saveChanges.setWhatsThis(
i18n( "Pressing this button will save all recent changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
KGuiItem discardChanges( KStdGuiItem::discard() );
discardChanges.setWhatsThis(
i18n( "Pressing this button will discard all recent changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
//dialog's data is dirty:
//--adidional message, e.g. table designer will return
@@ -3243,7 +3243,7 @@ tristate KexiMainWindowImpl::closeDialog(KexiDialogBase *dlg, bool layoutTaskBar
const int questionRes = KMessageBox::warningYesNoCancel( this,
"<p>"+dlg->part()->i18nMessage("Design of object \"%1\" has been modified.", dlg)
- .tqarg(dlg->partItem()->name())+"</p><p>"+i18n("Do you want to save changes?")+"</p>"
+ .arg(dlg->partItem()->name())+"</p><p>"+i18n("Do you want to save changes?")+"</p>"
+ additionalMessage /*may be empty*/,
TQString(),
saveChanges,
@@ -3380,9 +3380,9 @@ void KexiMainWindowImpl::attachWindow(KMdiChildView *pWnd, bool /*bShow*/, bool
KMdiMainFrm::attachWindow(pWnd,true,bAutomaticResize);
//for dialogs in normal state: decrease dialog's height if it exceeds area contents
if (pWnd->mdiParent()->state() == KMdiChildFrm::Normal
- && pWnd->tqgeometry().bottom() > pWnd->mdiParent()->mdiAreaContentsRect().bottom())
+ && pWnd->geometry().bottom() > pWnd->mdiParent()->mdiAreaContentsRect().bottom())
{
- TQRect r = pWnd->tqgeometry();
+ TQRect r = pWnd->geometry();
r.setBottom( pWnd->mdiParent()->mdiAreaContentsRect().bottom() - 5 );
pWnd->setGeometry( r );
}
@@ -3444,7 +3444,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
/* Fixes for popup menus behaviour:
For hiding/showing: focus previously (d->focus_before_popup)
focused window, if known, otherwise focus currently focused one.
- And: just tqinvalidate actions.
+ And: just invalidate actions.
*/
if (e->type()==TQEvent::Hide || e->type()==TQEvent::Show) {
KexiVDebug << e->type() << endl;
@@ -3481,8 +3481,8 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
#ifdef KEXI_STATUSBAR_DEBUG
TQWidget *focus_widget = focus_w ? focus_w->focusWidget() : 0;
d->statusBar->setStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
- .tqarg(focus_w ? focus_w->className() : "").tqarg(focus_w ? focus_w->name() : "")
- .tqarg(focus_widget ? focus_widget->className() : "").tqarg(focus_widget ? focus_widget->name() : "")
+ .arg(focus_w ? focus_w->className() : "").arg(focus_w ? focus_w->name() : "")
+ .arg(focus_widget ? focus_widget->className() : "").arg(focus_widget ? focus_widget->name() : "")
);
#endif
}
@@ -3494,8 +3494,8 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
#ifdef KEXI_STATUSBAR_DEBUG
TQWidget *focus_widget = focus_w ? focus_w->focusWidget() : 0;
d->statusBar->setStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
- .tqarg(focus_w ? focus_w->className() : "").tqarg(focus_w ? focus_w->name() : "")
- .tqarg(focus_widget ? focus_widget->className() : "").tqarg(focus_widget ? focus_widget->name() : "")
+ .arg(focus_w ? focus_w->className() : "").arg(focus_w ? focus_w->name() : "")
+ .arg(focus_widget ? focus_widget->className() : "").arg(focus_widget ? focus_widget->name() : "")
);
#endif
}
@@ -3534,7 +3534,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
return true;
}
//remember currently focued window tqinvalidate act.
if (e->type()==TQEvent::FocusOut) {
if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {
if (KexiUtils::hasParent(TQT_TQOBJECT(d->curDialog), TQT_TQOBJECT(focus_w))) {
@@ -3605,7 +3605,7 @@ KexiMainWindowImpl::openObject(KexiPart::Item* item, int viewMode, bool &opening
if (!openingAllowed(item, viewMode)) {
if (errorMessage)
*errorMessage = i18n("opening is not allowed in \"data view/design view/text view\" mode",
- "opening is not allowed in \"%1\" mode").tqarg(Kexi::nameForViewMode(viewMode));
+ "opening is not allowed in \"%1\" mode").arg(Kexi::nameForViewMode(viewMode));
openingCancelled = true;
return 0;
}
@@ -3790,7 +3790,7 @@ tristate KexiMainWindowImpl::removeObject( KexiPart::Item *item, bool dontAsk )
"<p>"+i18n("Do you want to permanently delete:\n"
"%1\n"
"If you click \"Delete\", you will not be able to undo the deletion.")
- .tqarg( "</p><p>"+part->instanceCaption()+" \""+ item->name() + "\"?</p>" ),
+ .arg( "</p><p>"+part->instanceCaption()+" \""+ item->name() + "\"?</p>" ),
0, KGuiItem(i18n("Delete"), "editdelete"), KStdGuiItem::no()))
return cancelled;
}
@@ -3865,7 +3865,7 @@ void KexiMainWindowImpl::renameObject( KexiPart::Item *item, const TQString& _ne
const bool res = d->prj->renameObject(this, *item, newName);
enableMessages(true);
if (!res) {
- showErrorMessage( d->prj, i18n("Renaming object \"%1\" failed.").tqarg(newName) );
+ showErrorMessage( d->prj, i18n("Renaming object \"%1\" failed.").arg(newName) );
success = false;
return;
}
@@ -3980,7 +3980,7 @@ void KexiMainWindowImpl::importantInfo(bool /*onStartup*/)
if (onStartup && !d->showImportantInfoOnStartup)
return;
- TQString key = TQString("showImportantInfo %1").tqarg(KEXI_VERSION_STRING);
+ TQString key = TQString("showImportantInfo %1").arg(KEXI_VERSION_STRING);
d->config->setGroup("Startup");
bool show = d->config->readBoolEntry(key,true);
@@ -4005,7 +4005,7 @@ void KexiMainWindowImpl::importantInfo(bool /*onStartup*/)
ts.setCodec( KGlobal::locale()->codecForEncoding() );
TQTextBrowser *tb = KexiUtils::findFirstChild<KTextBrowser>(&tipDialog,"KTextBrowser");
if (tb) {
- tb->setText( TQString("<qt>%1</qt>").tqarg(ts.read()) );
+ tb->setText( TQString("<qt>%1</qt>").arg(ts.read()) );
}
f.close();
}
@@ -4062,7 +4062,7 @@ KexiMainWindowImpl::initUserMode(KexiProjectData *projectData)
#if 0 //todo reenable; autoopen objects are handled elsewhere
KexiDB::TableSchema *sch = d->prj->dbConnection()->tableSchema("kexi__final");
TQString err_msg = i18n("Could not start project \"%1\" in Final Mode.")
- .tqarg(static_cast<KexiDB::SchemaData*>(projectData)->name());
+ .arg(static_cast<KexiDB::SchemaData*>(projectData)->name());
if(!sch)
{
hide();
@@ -4184,7 +4184,7 @@ void KexiMainWindowImpl::slotToolsCompactDatabase()
if (!drv || !(drv->features() & KexiDB::Driver::CompactingDatabaseSupported)) {
KMessageBox::information(this, "<qt>"+
i18n("Compacting database file <nobr>\"%1\"</nobr> is not supported.")
- .tqarg(TQDir::convertSeparators(cdata.fileName())));
+ .arg(TQDir::convertSeparators(cdata.fileName())));
return;
}
data = new KexiProjectData( cdata, cdata.fileName() );
@@ -4423,11 +4423,11 @@ tristate KexiMainWindowImpl::printActionForItem(KexiPart::Item* item, PrintActio
saveChanges.setToolTip(i18n("Save changes"));
saveChanges.setWhatsThis(
i18n( "Pressing this button will save all recent changes made in \"%1\" object." )
- .tqarg(item->name()) );
+ .arg(item->name()) );
KGuiItem doNotSave( KStdGuiItem::no() );
doNotSave.setWhatsThis(
i18n( "Pressing this button will ignore all unsaved changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
TQString question;
if (action == PrintItem)
@@ -4441,7 +4441,7 @@ tristate KexiMainWindowImpl::printActionForItem(KexiPart::Item* item, PrintActio
const int questionRes = KMessageBox::warningYesNoCancel( this,
"<p>"+dlg->part()->i18nMessage("Design of object \"%1\" has been modified.", dlg)
- .tqarg(item->name()) + "</p><p>" + question + "</p>",
+ .arg(item->name()) + "</p><p>" + question + "</p>",
TQString(),
saveChanges,
doNotSave);
@@ -111,7 +111,7 @@
# define KexiVDebug if (0) kdDebug()
#endif
-//first fix the tqgeometry
+//first fix the geometry
//#define KEXI_NO_CTXT_HELP 1
#ifndef KEXI_NO_CTXT_HELP
@@ -3534,7 +3534,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
return true;
}
- //remember currently focued window tqinvalidate act.
+ //remember currently focued window invalidate act.
if (e->type()==TQEvent::FocusOut) {
if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {
diff --git a/kexi/main/kexistatusbar.cpp b/kexi/main/kexistatusbar.cpp
index 439c20b6..02778208 100644
--- a/kexi/main/kexistatusbar.cpp
+++ b/kexi/main/kexistatusbar.cpp
@@ -33,14 +33,14 @@
#include <klocale.h>
#include <kparts/part.h>
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
#include <ktexteditor/viewcursorinterface.h>
#include <ktexteditor/viewstatusmsginterface.h>
#endif
-KexiStatusBar::KexiStatusBar(TQWidget *parent, const char *name)
+KexitStatusBar::KexitStatusBar(TQWidget *parent, const char *name)
: KStatusBar(parent, name)
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
, m_cursorIface(0)
#endif
, m_activePart(0)
@@ -61,17 +61,17 @@ KexiStatusBar::KexiStatusBar(TQWidget *parent, const char *name)
}
-KexiStatusBar::~KexiStatusBar()
+KexitStatusBar::~KexitStatusBar()
{
}
-void KexiStatusBar::activePartChanged(KParts::Part *part)
+void KexitStatusBar::activePartChanged(KParts::Part *part)
{
if ( m_activePart && m_activePart->widget() )
disconnect( m_activePart->widget(), 0, this, 0 );
m_activePart = part;
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
m_cursorIface = 0;
m_viewmsgIface = 0;
// @todo
@@ -98,9 +98,9 @@ void KexiStatusBar::activePartChanged(KParts::Part *part)
}
-void KexiStatusBar::cursorPositionChanged()
+void KexitStatusBar::cursorPositionChanged()
{
-#if KexiStatusBar_KTEXTEDITOR_USED
+#if KexitStatusBar_KTEXTEDITOR_USED
if (m_cursorIface)
{
uint line, col;
@@ -110,9 +110,9 @@ void KexiStatusBar::cursorPositionChanged()
#endif
}
-void KexiStatusBar::setStatus(const TQString &str)
+void KexitStatusBar::setStatus(const TQString &str)
{
- kdDebug() << "KexiStatusBar::setStatus(" << str << ")" << endl;
+ kdDebug() << "KexitStatusBar::setStatus(" << str << ")" << endl;
// m_status->setText(str);
changeItem(str, m_msgID);
@@ -123,13 +123,13 @@ void KexiStatusBar::setStatus(const TQString &str)
#endif
}
-void KexiStatusBar::setCursorPosition(int line, int col)
+void KexitStatusBar::setCursorPosition(int line, int col)
{
-// m_status->setText(i18n(" Line: %1 Col: %2 ").tqarg(line+1).tqarg(col));
- changeItem(i18n(" Line: %1 Col: %2 ").tqarg(line+1).tqarg(col), m_msgID);
+// m_status->setText(i18n(" Line: %1 Col: %2 ").arg(line+1).arg(col));
+ changeItem(i18n(" Line: %1 Col: %2 ").arg(line+1).arg(col), m_msgID);
}
/*void KexiStatusBar::addWidget ( TQWidget *widget, int stretch, bool permanent)
{
KStatusBar::addWidget(widget,stretch,permanent);
@@ -137,7 +137,7 @@ void KexiStatusBar::setCursorPosition(int line, int col)
setFixedHeight(widget->sizeHint().height() + 4);
}*/
-void KexiStatusBar::setReadOnlyFlag(bool readOnly)
+void KexitStatusBar::setReadOnlyFlag(bool readOnly)
{
changeItem(readOnly ? i18n("Read only") : TQString(), m_readOnlyID);
}
@@ -123,13 +123,13 @@ void KexiStatusBar::setStatus(const TQString &str)
}
-/*void KexiStatusBar::addWidget ( TQWidget *widget, int stretch, bool permanent)
+/*void KexitStatusBar::addWidget ( TQWidget *widget, int stretch, bool permanent)
{
KStatusBar::addWidget(widget,stretch,permanent);